// This file is generated by kconfig_compiler_kf6 from libkcddb5.kcfg.
// All changes you do to this file will be lost.
#ifndef CONFIGBASE_H
#define CONFIGBASE_H

#include "kcddb_export.h"

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

#include <QDir>

class ConfigBasePrivate;

class KCDDB_EXPORT ConfigBase : public KConfigSkeleton
{
  public:
    class EnumFreedbLookupTransport
    {
      public:
      enum type { CDDBP, HTTP, COUNT };
    };

    ConfigBase( );
    ~ConfigBase() override;

    /**
      Set hostname
    */
    void setHostname( const QString & v );

    /**
      Get hostname
    */
    QString hostname() const;

    /**
      Is hostname Immutable
    */
    bool isHostnameImmutable() const;

    /**
      Set port
    */
    void setPort( int v );

    /**
      Get port
    */
    int port() const;

    /**
      Is port Immutable
    */
    bool isPortImmutable() const;

    /**
      Set MusicBrainzLookupEnabled
    */
    void setMusicBrainzLookupEnabled( bool v );

    /**
      Get MusicBrainzLookupEnabled
    */
    bool musicBrainzLookupEnabled() const;

    /**
      Is MusicBrainzLookupEnabled Immutable
    */
    bool isMusicBrainzLookupEnabledImmutable() const;

    /**
      Set FreedbLookupEnabled
    */
    void setFreedbLookupEnabled( bool v );

    /**
      Get FreedbLookupEnabled
    */
    bool freedbLookupEnabled() const;

    /**
      Is FreedbLookupEnabled Immutable
    */
    bool isFreedbLookupEnabledImmutable() const;

    /**
      Set CacheLookupEnabled
    */
    void setCacheLookupEnabled( bool v );

    /**
      Get CacheLookupEnabled
    */
    bool cacheLookupEnabled() const;

    /**
      Is CacheLookupEnabled Immutable
    */
    bool isCacheLookupEnabledImmutable() const;

    /**
      Set FreedbLookupTransport
    */
    void setFreedbLookupTransport( int v );

    /**
      Get FreedbLookupTransport
    */
    int freedbLookupTransport() const;

    /**
      Is FreedbLookupTransport Immutable
    */
    bool isFreedbLookupTransportImmutable() const;

    /**
      Set cacheLocations
    */
    void setCacheLocations( const QStringList & v );

    /**
      Get cacheLocations
    */
    QStringList cacheLocations() const;

    /**
      Is cacheLocations Immutable
    */
    bool isCacheLocationsImmutable() const;

    /**
      Set emailAddress
    */
    void setEmailAddress( const QString & v );

    /**
      Get emailAddress
    */
    QString emailAddress() const;

    /**
      Is emailAddress Immutable
    */
    bool isEmailAddressImmutable() const;

    /**
      Set httpSubmitServer
    */
    void setHttpSubmitServer( const QString & v );

    /**
      Get httpSubmitServer
    */
    QString httpSubmitServer() const;

    /**
      Is httpSubmitServer Immutable
    */
    bool isHttpSubmitServerImmutable() const;

    /**
      Set httpSubmitPort
    */
    void setHttpSubmitPort( int v );

    /**
      Get httpSubmitPort
    */
    int httpSubmitPort() const;

    /**
      Is httpSubmitPort Immutable
    */
    bool isHttpSubmitPortImmutable() const;

  protected:
  private:
    ConfigBasePrivate *d;
};

#endif

